@@ -1,33 +1,16 @@
 /*
-    This file is part of the KDE project
-
-    Copyright (c) 2006 - 2009 John Tapsell <tapsell@kde.org>
-
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License as
- published by the Free Software Foundation; either version 2 of
- the License or (at your option) version 3 or any later version
- accepted by the membership of KDE e.V. (or its successor approved
- by the membership of KDE e.V.), which shall act as a proxy 
- defined in Section 14 of version 3 of the license.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-FileCopyrightText: 2006-2009 John Tapsell <tapsell@kde.org>
 
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #ifndef KSIGNALPLOTTER_H
 #define KSIGNALPLOTTER_H
 
-#include <QList>
-#include <QString>
 #include <QColor>
 #include <QFont>
+#include <QList>
+#include <QString>
 #include <QWidget>
 #include <klocalizedstring.h>
 
@@ -36,7 +19,7 @@ class QResizeEvent;
 
 class KSignalPlotterPrivate;
 
-//Make sure only declare KLocalizedString once
+// Make sure only declare KLocalizedString once
 #ifndef KGRAPHICSSIGNALPLOTTER_H
 Q_DECLARE_METATYPE(KLocalizedString)
 #endif
@@ -71,27 +54,27 @@ Q_DECLARE_METATYPE(KLocalizedString)
  */
 class Q_DECL_EXPORT KSignalPlotter : public QWidget
 {
-  Q_OBJECT
-  Q_PROPERTY(qreal minimumValue READ minimumValue WRITE setMinimumValue)
-  Q_PROPERTY(qreal maximumValue READ maximumValue WRITE setMaximumValue)
-  Q_PROPERTY(bool useAutoRange READ useAutoRange WRITE setUseAutoRange)
-  Q_PROPERTY(KLocalizedString unit READ unit WRITE setUnit)
-  Q_PROPERTY(qreal scaleDownBy READ scaleDownBy WRITE setScaleDownBy)
-  Q_PROPERTY(uint horizontalScale READ horizontalScale WRITE setHorizontalScale)
-  Q_PROPERTY(bool showHorizontalLines READ showHorizontalLines WRITE setShowHorizontalLines)
-  Q_PROPERTY(bool showVerticalLines READ showVerticalLines WRITE setShowVerticalLines)
-  Q_PROPERTY(bool verticalLinesScroll READ verticalLinesScroll WRITE setVerticalLinesScroll)
-  Q_PROPERTY(uint verticalLinesDistance READ verticalLinesDistance WRITE setVerticalLinesDistance)
-  Q_PROPERTY(bool showAxis READ showAxis WRITE setShowAxis)
-  Q_PROPERTY(QString svgBackground READ svgBackground WRITE setSvgBackground)
-  Q_PROPERTY(bool thinFrame READ thinFrame WRITE setThinFrame)
-  Q_PROPERTY(int maxAxisTextWidth READ maxAxisTextWidth WRITE setMaxAxisTextWidth)
-  Q_PROPERTY(bool smoothGraph READ smoothGraph WRITE setSmoothGraph)
-  Q_PROPERTY(bool stackGraph READ stackGraph WRITE setStackGraph)
-  Q_PROPERTY(int fillOpacity READ fillOpacity WRITE setFillOpacity)
+    Q_OBJECT
+    Q_PROPERTY(qreal minimumValue READ minimumValue WRITE setMinimumValue)
+    Q_PROPERTY(qreal maximumValue READ maximumValue WRITE setMaximumValue)
+    Q_PROPERTY(bool useAutoRange READ useAutoRange WRITE setUseAutoRange)
+    Q_PROPERTY(KLocalizedString unit READ unit WRITE setUnit)
+    Q_PROPERTY(qreal scaleDownBy READ scaleDownBy WRITE setScaleDownBy)
+    Q_PROPERTY(uint horizontalScale READ horizontalScale WRITE setHorizontalScale)
+    Q_PROPERTY(bool showHorizontalLines READ showHorizontalLines WRITE setShowHorizontalLines)
+    Q_PROPERTY(bool showVerticalLines READ showVerticalLines WRITE setShowVerticalLines)
+    Q_PROPERTY(bool verticalLinesScroll READ verticalLinesScroll WRITE setVerticalLinesScroll)
+    Q_PROPERTY(uint verticalLinesDistance READ verticalLinesDistance WRITE setVerticalLinesDistance)
+    Q_PROPERTY(bool showAxis READ showAxis WRITE setShowAxis)
+    Q_PROPERTY(QString svgBackground READ svgBackground WRITE setSvgBackground)
+    Q_PROPERTY(bool thinFrame READ thinFrame WRITE setThinFrame)
+    Q_PROPERTY(int maxAxisTextWidth READ maxAxisTextWidth WRITE setMaxAxisTextWidth)
+    Q_PROPERTY(bool smoothGraph READ smoothGraph WRITE setSmoothGraph)
+    Q_PROPERTY(bool stackGraph READ stackGraph WRITE setStackGraph)
+    Q_PROPERTY(int fillOpacity READ fillOpacity WRITE setFillOpacity)
 
-  public:
-    KSignalPlotter( QWidget *parent = nullptr);
+public:
+    explicit KSignalPlotter(QWidget *parent = nullptr);
     ~KSignalPlotter() override;
 
     /** \brief Add a new line to the graph plotter, with the specified color.
@@ -101,7 +84,7 @@ class Q_DECL_EXPORT KSignalPlotter : public QWidget
      *
      *  \param color Color of beam - does not have to be unique.
      */
-    void addBeam( const QColor &color );
+    void addBeam(const QColor &color);
 
     /** \brief Add data to the graph, and advance the graph by one time period.
      *
@@ -128,7 +111,7 @@ class Q_DECL_EXPORT KSignalPlotter : public QWidget
      *  Infinity is handled by drawing a straight line up to the top or bottom of the display, and does not affect the range.
      *  For the above example, the displayed range would now be 0 to 10.
      */
-    void addSample( const QList<qreal> &samples );
+    void addSample(const QList<qreal> &samples);
 
     /** \brief Reorder the beams into the order given.
      *
@@ -147,14 +130,14 @@ class Q_DECL_EXPORT KSignalPlotter : public QWidget
      * The size of the \p newOrder list must be equal to the result of numBeams().
      * \param newOrder New order of beams.
      */
-    void reorderBeams( const QList<int>& newOrder );
+    void reorderBeams(const QList<int> &newOrder);
 
     /** \brief Removes the beam at the specified index.
      *
      * This causes the graph to be redrawn with the specified beam completely
      * removed.
      */
-    void removeBeam( int index );
+    void removeBeam(int index);
 
     /** \brief Get the color of the beam at the specified index.
      *
@@ -170,13 +153,13 @@ class Q_DECL_EXPORT KSignalPlotter : public QWidget
      *
      * \sa setBeamColor()
      */
-    QColor beamColor( int index ) const;
+    QColor beamColor(int index) const;
 
     /** \brief Set the color of the beam at the specified index.
      *
      * \sa beamColor()
      */
-    void setBeamColor( int index, const QColor &color );
+    void setBeamColor(int index, const QColor &color);
 
     /** \brief Returns the number of beams. */
     int numBeams() const;
@@ -200,7 +183,7 @@ class Q_DECL_EXPORT KSignalPlotter : public QWidget
      *
      * \see unit(), setScaleDownBy()
      */
-    void setUnit( const KLocalizedString &unit );
+    void setUnit(const KLocalizedString &unit);
 
     /** \brief The localizable units used on the vertical axis of the graph.
      *
@@ -221,7 +204,7 @@ class Q_DECL_EXPORT KSignalPlotter : public QWidget
      * Typically this is followed by calling setUnit() to set the display axis
      * units.  Default value is 1.
      */
-    void setScaleDownBy( qreal value );
+    void setScaleDownBy(qreal value);
 
     /** \brief Amount scaled down by.
      *
@@ -241,7 +224,7 @@ class Q_DECL_EXPORT KSignalPlotter : public QWidget
      *
      * \sa useAutoRange
      */
-    void setUseAutoRange( bool value );
+    void setUseAutoRange(bool value);
 
     /** \brief Whether the vertical axis range is set automatically.
      */
@@ -267,12 +250,12 @@ class Q_DECL_EXPORT KSignalPlotter : public QWidget
      *
      *  \sa setMinimumValue(), setMaximumValue(), minimumValue(), maximumValue()
      */
-    void changeRange( qreal min, qreal max );
+    void changeRange(qreal min, qreal max);
 
     /** \brief Set the min value hint for the vertical axis.
      *
      * \sa changeRange(), minimumValue(), setMaximumValue(), maximumValue() */
-    void setMinimumValue( qreal min );
+    void setMinimumValue(qreal min);
 
     /** \brief Get the min value hint for the vertical axis.
      *
@@ -282,7 +265,7 @@ class Q_DECL_EXPORT KSignalPlotter : public QWidget
     /** \brief Set the max value hint for the vertical axis. *
      *
      * \sa changeRange(), minimumValue(), setMaximumValue(), maximumValue() */
-    void setMaximumValue( qreal max );
+    void setMaximumValue(qreal max);
 
     /** \brief Get the maximum value hint for the vertical axis.
      *
@@ -306,14 +289,14 @@ class Q_DECL_EXPORT KSignalPlotter : public QWidget
 
     /** \brief Set the number of pixels horizontally between data points.
      *  Default is 6. */
-    void setHorizontalScale( uint scale );
+    void setHorizontalScale(uint scale);
     /** \brief The number of pixels horizontally between data points.
      *  Default is 6. */
     int horizontalScale() const;
 
     /** \brief Set whether to draw the vertical grid lines.
      *  Default is false. */
-    void setShowVerticalLines( bool value );
+    void setShowVerticalLines(bool value);
     /** \brief Whether to draw the vertical grid lines.
      *  Default is false. */
     bool showVerticalLines() const;
@@ -321,21 +304,21 @@ class Q_DECL_EXPORT KSignalPlotter : public QWidget
     /** \brief Set the horizontal distance, in pixels, between the vertical grid lines.
      *  Must be a distance of 1 or more.
      *  Default is 30 pixels. */
-    void setVerticalLinesDistance( uint distance );
+    void setVerticalLinesDistance(uint distance);
     /** \brief The horizontal distance, in pixels, between the vertical grid lines.
-      *  Default is 30 pixels. */
+     *  Default is 30 pixels. */
     uint verticalLinesDistance() const;
 
     /** \brief Set whether the vertical lines move with the data.
      *  Default is true. This has no effect is showVerticalLines is false. */
-    void setVerticalLinesScroll( bool value );
+    void setVerticalLinesScroll(bool value);
     /** \brief Whether the vertical lines move with the data.
      *  Default is true. This has no effect is showVerticalLines is false. */
     bool verticalLinesScroll() const;
 
     /** \brief Set whether to draw the horizontal grid lines.
      *  Default is true. */
-    void setShowHorizontalLines( bool value );
+    void setShowHorizontalLines(bool value);
     /** \brief Whether to draw the horizontal grid lines.
      *  Default is true. */
     bool showHorizontalLines() const;
@@ -349,7 +332,7 @@ class Q_DECL_EXPORT KSignalPlotter : public QWidget
      *
      * Default is true.
      * \sa showAxis(), setAxisFont(), setAxisFontColor(), setMaxAxisTextWidth() */
-    void setShowAxis( bool show );
+    void setShowAxis(bool show);
     /** \brief Whether to show the vertical axis labels.
      *
      * Default is true.
@@ -359,7 +342,7 @@ class Q_DECL_EXPORT KSignalPlotter : public QWidget
     /** \brief Set the filename of the SVG background.
      *
      * Set to empty (default) to disable again. */
-    void setSvgBackground( const QString &filename );
+    void setSvgBackground(const QString &filename);
 
     /** \brief The filename of the SVG background. */
     QString svgBackground() const;
@@ -367,7 +350,7 @@ class Q_DECL_EXPORT KSignalPlotter : public QWidget
     /** \brief Return the last value that we have for the given beam index.
      *
      * \return last value, or 0 if not known. */
-    qreal lastValue( int index) const;
+    qreal lastValue(int index) const;
 
     /** \brief Return a translated string for the last value at the given index.
      *
@@ -377,7 +360,7 @@ class Q_DECL_EXPORT KSignalPlotter : public QWidget
      * If precision is -1 (the default) then if @p value is greater than 99.5, no decimal figures are shown,
      * otherwise if @p value is greater than 0.995, 1 decimal figure is used, otherwise 2.
      */
-    QString lastValueAsString( int index, int precision = -1) const;
+    QString lastValueAsString(int index, int precision = -1) const;
 
     /** \brief Return a translated string for the given value.
      *
@@ -395,7 +378,7 @@ class Q_DECL_EXPORT KSignalPlotter : public QWidget
      * \endcode
      *
      */
-    QString valueAsString( qreal value, int precision = -1) const;
+    QString valueAsString(qreal value, int precision = -1) const;
 
     /** \brief Set the distance between the left of the widget and the left of the plotting region.
      *
@@ -443,19 +426,19 @@ class Q_DECL_EXPORT KSignalPlotter : public QWidget
     /* Set whether to show a thin line on the left and bottom of the widget, for a slight 3D effect */
     void setThinFrame(bool thinFrame);
 
-  Q_SIGNALS:
+Q_SIGNALS:
     /** When the axis has changed this signal is emitted. */
     void axisScaleChanged();
 
-  protected:
+protected:
     /* Reimplemented */
-    void resizeEvent( QResizeEvent* ) override;
-    void paintEvent( QPaintEvent* ) override;
+    void resizeEvent(QResizeEvent *) override;
+    void paintEvent(QPaintEvent *) override;
     QSize sizeHint() const override;
-    void changeEvent ( QEvent * event ) override;
+    void changeEvent(QEvent *event) override;
 
-  private:
-    KSignalPlotterPrivate * const d;
+private:
+    KSignalPlotterPrivate *const d;
     friend class KSignalPlotterPrivate;
 };
 
